import { createRoot } from 'react-dom/client'
import { HelmetProvider } from 'react-helmet-async'
import App from './App'
import './index.css'

// Add resource hints for faster loading
const addResourceHints = () => {
  // DNS prefetch for external resources
  const dnsPrefetch = document.createElement('link');
  dnsPrefetch.rel = 'dns-prefetch';
  dnsPrefetch.href = '//fonts.googleapis.com';
  document.head.appendChild(dnsPrefetch);

  // Preconnect to font resources
  const preconnect = document.createElement('link');
  preconnect.rel = 'preconnect';
  preconnect.href = 'https://fonts.gstatic.com';
  preconnect.crossOrigin = 'anonymous';
  document.head.appendChild(preconnect);
};

// Preload critical resources with proper prioritization
const preloadCriticalResources = () => {
  // Preload critical fonts with font-display swap
  const fontLink = document.createElement('link');
  fontLink.rel = 'preload';
  fontLink.href = 'https://fonts.googleapis.com/css2?family=Poppins:wght@400;600;700&family=Montserrat:wght@400;500;600&display=swap';
  fontLink.as = 'style';
  fontLink.onload = () => {
    fontLink.rel = 'stylesheet';
  };
  document.head.appendChild(fontLink);

  // Preload hero images with high priority
  const heroImageDesktop = new Image();
  heroImageDesktop.src = '/lovable-uploads/physio-cure-dubai-ab-crunch-exercise.jpg';
  heroImageDesktop.fetchPriority = 'high';
  
  const heroImageMobile = new Image();
  heroImageMobile.src = '/lovable-uploads/physio-cure-dubai-ab-crunch-exercise-mob-OPT.jpg';
  heroImageMobile.fetchPriority = 'high';

  // Preload doctor images for Meet Expert section
  const drMinaImage = new Image();
  drMinaImage.src = '/lovable-uploads/d28fd751-230a-4753-a230-33bf3d7e2b44.png';
  drMinaImage.fetchPriority = 'high';

  const drShaimaaImage = new Image();
  drShaimaaImage.src = '/lovable-uploads/c245db29-814c-4377-b74b-2506793a3a5f.png';
  drShaimaaImage.fetchPriority = 'high';

  const drTalaatImage = new Image();
  drTalaatImage.src = '/lovable-uploads/a6b6fcbb-bbfd-4cee-b875-e797d6a8cfdd.png';
  drTalaatImage.fetchPriority = 'high';

  // Smart preloading for treatment pages based on current path
  const currentPath = window.location.pathname;
  if (currentPath.includes('/orthopedic-physiotherapy')) {
    const orthopedicDesktop = new Image();
    orthopedicDesktop.src = '/lovable-uploads/orthopedic-physiotherapy-at-physio-cure-in-dubai_desktop.jpg';
    orthopedicDesktop.fetchPriority = 'high';
    
    const orthopedicMobile = new Image();
    orthopedicMobile.src = '/lovable-uploads/orthopedic-physiotherapy-at-physio-cure-in-dubai.jpg';
    orthopedicMobile.fetchPriority = 'high';
  } else if (currentPath.includes('/acl-treatment')) {
    const aclDesktop = new Image();
    aclDesktop.src = '/lovable-uploads/acl-treatment_desktop.jpg';
    aclDesktop.fetchPriority = 'high';
    
    const aclMobile = new Image();
    aclMobile.src = '/lovable-uploads/acl-treatment.jpg';
    aclMobile.fetchPriority = 'high';
  }
};

// Initialize performance optimizations immediately
addResourceHints();
preloadCriticalResources();

export function hydrate() {
  const container = document.getElementById('root');
  if (container) {
    createRoot(container).render(
      <HelmetProvider>
        <App />
      </HelmetProvider>
    );
  }
}

